@@ -334,13 +334,13 @@ read_lustre_counter( )
 			if (fgets(buffer,BUFSIZ,fff)==NULL) break;
 	
 			if (strstr( buffer, "write_bytes" )) {
-			  sscanf(buffer,"%*s %*d %*s %*s %*d %*d %lld",&fs->write_cntr->value);
-			  SUBDBG("Read %lld write_bytes\n",fs->write_cntr->value);
+			  sscanf(buffer,"%*s %*d %*s %*s %*d %*d %llu",&fs->write_cntr->value);
+			  SUBDBG("Read %llu write_bytes\n",fs->write_cntr->value);
 			}
 	
 			if (strstr( buffer, "read_bytes" )) {
-			  sscanf(buffer,"%*s %*d %*s %*s %*d %*d %lld",&fs->read_cntr->value);
-			  SUBDBG("Read %lld read_bytes\n",fs->read_cntr->value);
+			  sscanf(buffer,"%*s %*d %*s %*s %*d %*d %llu",&fs->read_cntr->value);
+			  SUBDBG("Read %llu read_bytes\n",fs->read_cntr->value);
 			}
 		  }
 		  fclose(fff);
@@ -352,8 +352,8 @@ read_lustre_counter( )
 			if (fgets(buffer,BUFSIZ,fff)==NULL) break;
 	
 			if (strstr( buffer, "read but discarded")) {
-			   sscanf(buffer,"%*s %*s %*s %lld",&fs->readahead_cntr->value);
-			   SUBDBG("Read %lld discared\n",fs->readahead_cntr->value);
+			   sscanf(buffer,"%*s %*s %*s %llu",&fs->readahead_cntr->value);
+			   SUBDBG("Read %llu discared\n",fs->readahead_cntr->value);
 			   break;
 			}
 	  	  }
@@ -678,18 +678,9 @@ int
 _lustre_set_domain( hwd_control_state_t * cntrl, int domain )
 {
 	( void ) cntrl;
-	int found = 0;
-	if ( PAPI_DOM_USER & domain ) {
-		found = 1;
-	}
-	if ( PAPI_DOM_KERNEL & domain ) {
-		found = 1;
-	}
-	if ( PAPI_DOM_OTHER & domain ) {
-		found = 1;
-	}
-	if ( !found )
+	if ( PAPI_DOM_USER != domain ) {
 		return PAPI_EINVAL;
+	}
 
 	return PAPI_OK;
 }
@@ -770,9 +761,9 @@ papi_vector_t _lustre_vector = {
        .description = "Lustre filesystem statistics",
        .num_mpx_cntrs = LUSTRE_MAX_COUNTERS,
        .num_cntrs = LUSTRE_MAX_COUNTERS,
-       .default_domain = PAPI_DOM_USER,
-       .default_granularity = PAPI_GRN_THR,
-       .available_granularities = PAPI_GRN_THR,
+       .default_domain = PAPI_DOM_ALL,
+       .default_granularity = PAPI_GRN_SYS,
+       .available_granularities = PAPI_GRN_SYS,
        .hardware_intr_sig = PAPI_INT_SIGNAL,
 
        /* component specific cmp_info initializations */
@@ -780,7 +771,7 @@ papi_vector_t _lustre_vector = {
        .fast_virtual_timer = 0,
        .attach = 0,
        .attach_must_ptrace = 0,
-       .available_domains = PAPI_DOM_USER | PAPI_DOM_KERNEL,
+       .available_domains = PAPI_DOM_ALL,
   },
 
      /* sizes of framework-opaque component-private structures */
