@@ -240,7 +240,7 @@ read_net_counters( long long *values )
             SUBDBG("Interface <%s> not found\n", ifname);
         } else {
             nf = sscanf( data,
-                "%llu %llu %llu %llu %llu %llu %llu %llu %llu %llu %llu %llu %llu %llu %llu %llu\n",
+                "%lld %lld %lld %lld %lld %lld %lld %lld %lld %lld %lld %lld %lld %lld %lld %lld\n",
                 &values[if_bidx + 0],  &values[if_bidx + 1],
                 &values[if_bidx + 2],  &values[if_bidx + 3],
                 &values[if_bidx + 4],  &values[if_bidx + 5],
@@ -251,7 +251,7 @@ read_net_counters( long long *values )
                 &values[if_bidx + 14], &values[if_bidx + 15]);
 
             SUBDBG("\nRead "
-                "%llu %llu %llu %llu %llu %llu %llu %llu %llu %llu %llu %llu %llu %llu %llu %llu\n",
+                "%lld %lld %lld %lld %lld %lld %lld %lld %lld %lld %lld %lld %lld %lld %lld %lld\n",
                 values[if_bidx + 0],  values[if_bidx + 1],
                 values[if_bidx + 2],  values[if_bidx + 3],
                 values[if_bidx + 4],  values[if_bidx + 5],
@@ -502,14 +502,7 @@ int
 _net_set_domain( hwd_control_state_t *ctl, int domain )
 {
     ( void ) ctl;
-
-    int found = 0;
-
-    if ( PAPI_DOM_USER & domain )   found = 1;
-    if ( PAPI_DOM_KERNEL & domain ) found = 1;
-    if ( PAPI_DOM_OTHER & domain )  found = 1;
-
-    if ( !found )
+    if ( PAPI_DOM_ALL != domain )
         return PAPI_EINVAL;
 
     return PAPI_OK;
@@ -646,10 +639,10 @@ papi_vector_t _net_vector = {
 	.description = "Linux network driver statistics",
         .num_mpx_cntrs         = NET_MAX_COUNTERS,
         .num_cntrs             = NET_MAX_COUNTERS,
-        .default_domain        = PAPI_DOM_USER,
-        //.available_domains   = PAPI_DOM_USER,
-        .default_granularity   = PAPI_GRN_THR,
-        .available_granularities = PAPI_GRN_THR,
+        .default_domain        = PAPI_DOM_ALL,
+        .available_domains   = PAPI_DOM_ALL,
+        .default_granularity   = PAPI_GRN_SYS,
+        .available_granularities = PAPI_GRN_SYS,
         .hardware_intr_sig     = PAPI_INT_SIGNAL,
 
         /* component specific cmp_info initializations */
@@ -657,7 +650,6 @@ papi_vector_t _net_vector = {
         .fast_virtual_timer    = 0,
         .attach                = 0,
         .attach_must_ptrace    = 0,
-        .available_domains     = PAPI_DOM_USER | PAPI_DOM_KERNEL,
     },
 
     /* sizes of framework-opaque component-private structures */
