@@ -353,12 +353,16 @@ static int map_perf_event_errors_to_papi(int perf_event_error) {
       case ENOSYS:
       case EAGAIN:
       case EBUSY:
-      case E2BIG:
+      case E2BIG:	/* Only happens if attr is the wrong size somehow */
+      case EBADF:	/* We are attempting to group with an invalid file descriptor */
 	   ret = PAPI_ESYS;
 	   break;
       case ENOMEM:
 	   ret = PAPI_ENOMEM;
 	   break;
+      case EMFILE:	/* Out of file descriptors.  Typically max out at 1024 */
+           ret = PAPI_ECOUNT;
+           break;
       case EINVAL:
       default:
 	   ret = PAPI_EINVAL;
@@ -651,7 +655,7 @@ open_pe_events( pe_context_t *ctx, pe_control_t *ctl )
 
       SUBDBG ("sys_perf_event_open: tid: %ld, cpu_num: %d,"
               " group_leader/fd: %d, event_fd: %d,"
-              " read_format: 0x%"PRIu64"\n",
+              " read_format: %#"PRIu64"\n",
 	      pid, ctl->cpu, ctl->events[i].group_leader_fd, 
 	      ctl->events[i].event_fd, ctl->events[i].attr.read_format);
 
@@ -1772,7 +1776,7 @@ mmap_read( int cidx, ThreadInfo_t **thr, pe_event_info_t *pe,
     case PERF_RECORD_LOST:
       SUBDBG( "Warning: because of a mmap buffer overrun, %" PRId64
                       " events were lost.\n"
-                      "Loss was recorded when counter id 0x%"PRIx64 
+                      "Loss was recorded when counter id %#"PRIx64 
 	      " overflowed.\n", event->lost.lost, event->lost.id );
       break;
 
