@@ -102,10 +102,28 @@ sys_perf_event_open( struct perf_event_attr *hw_event, pid_t pid, int cpu,
 {
    int ret;
 
-   SUBDBG("sys_perf_event_open(%p,%d,%d,%d,%lx\n",hw_event,pid,cpu,group_fd,flags);
+// If the comments on the following define symbol are removed, then applications that do not pass 
+// cpu numbers can be used with uncore events.  They will always get counts from the package which 
+// contains cpu 0 but at least they will work.  For instance this allows you to do uncore event testing 
+// with the papi_command_line utility.  But normally the cpu number to identify which package should 
+// be counted should be provided by the papi application so this should be commented out by default.
+// #define UNCORE_HELP 1
+#ifdef UNCORE_HELP
+   // A cpu number of -1 normally indicates that the caller does not want to limit counting to a specified cpu.
+   // But if a negative cpu number is passed to the kernel when counting uncore events, it will return an
+   // invalid argument error so we force the cpu number to zero in this case.  In uncore the cpu number is
+   // used by the kernel to specify which package should be counted so this code will set the default for
+   // counting uncore events to the package that contains cpu 0 (when not specified by the calling
+   // applicaiton).  Since uncore events are not associated with any cpu, it really does not matter
+   // which cpu number is used as a default.
+   if (cpu < 0)
+     cpu = 0;
+#endif
+
+   SUBDBG("sys_perf_event_open(hw_event: %p, pid: %d, cpu: %d, group_fd: %d, flags: %lx\n",hw_event,pid,cpu,group_fd,flags);
    SUBDBG("   type: %d\n",hw_event->type);
    SUBDBG("   size: %d\n",hw_event->size);
-   SUBDBG("   config: %"PRIx64" (%"PRIu64")\n",hw_event->config,
+   SUBDBG("   config: %#"PRIx64" (%"PRIu64")\n",hw_event->config,
 	  hw_event->config);
    SUBDBG("   sample_period: %"PRIu64"\n",hw_event->sample_period);
    SUBDBG("   sample_type: %"PRIu64"\n",hw_event->sample_type);
@@ -125,6 +143,20 @@ sys_perf_event_open( struct perf_event_attr *hw_event, pid_t pid, int cpu,
    SUBDBG("   enable_on_exec: %d\n",hw_event->enable_on_exec);
    SUBDBG("   task: %d\n",hw_event->task);
    SUBDBG("   watermark: %d\n",hw_event->watermark);
+   SUBDBG("   precise_ip: %d\n",hw_event->precise_ip);
+   SUBDBG("   mmap_data: %d\n",hw_event->mmap_data);
+   SUBDBG("   sample_id_all: %d\n",hw_event->sample_id_all);
+   SUBDBG("   exclude_host: %d\n",hw_event->exclude_host);
+   SUBDBG("   exclude_guest: %d\n",hw_event->exclude_guest);
+   SUBDBG("   exclude_callchain_kernel: %d\n",hw_event->exclude_callchain_kernel);
+   SUBDBG("   exclude_callchain_user: %d\n",hw_event->exclude_callchain_user);
+   SUBDBG("   wakeup_watermark: %d\n",hw_event->wakeup_watermark);
+   SUBDBG("   bp_type: %d\n",hw_event->bp_type);
+   SUBDBG("   config1: %#lx (%lu)\n",hw_event->config1,hw_event->config1);
+   SUBDBG("   config2: %#lx (%lu)\n",hw_event->config2,hw_event->config2);
+   SUBDBG("   branch_sample_type: %lu\n",hw_event->branch_sample_type);
+   SUBDBG("   sample_regs_user: %lu\n",hw_event->sample_regs_user);
+   SUBDBG("   sample_stack_user: %d\n",hw_event->sample_stack_user);
 
 	ret =
 		syscall( __NR_perf_event_open, hw_event, pid, cpu, group_fd, flags );
@@ -200,6 +232,30 @@ open_pe_events( pe_context_t *ctx, pe_control_t *ctl )
       /* set up the attr structure.  We don't set up all fields here */
       /* as some have already been set up previously.                */
 
+/*
+ * The following code controls how the uncore component interfaces with the 
+ * kernel for uncore events.  The code inside the ifdef will use grouping of 
+ * uncore events which can make the cost of reading the results more efficient.
+ * The problem with it is that the uncore component supports 20 different uncore 
+ * PMU's.  The kernel requires that all events in a group must be for the same PMU.
+ * This means that with grouping enabled papi applications can count events on only
+ * one of the 20 PMU's during a run.
+ * 
+ * The code inside the else clause treats each event in the event set as 
+ * independent.  When running in this mode the kernel allows the papi multiple 
+ * uncore PMU's at the same time.
+ * 
+ * Example:
+ *  An application wants to measure all the L3 cache write requests.
+ *  The event to do this is part of a cbox pmu (there are 8 cbox pmu's).
+ *  When built with the code in the ifdef, the application would have to be 
+ *    run 8 times and count write requests from one pmu at a time.
+ *  When built with the code in the else, the write requests in all 8 cbox 
+ *    pmu's could be counted in the same run.
+ * 
+ */
+// #define GROUPIT 1       // remove the comment on this line to force event grouping
+#ifdef GROUPIT
       /* group leader (event 0) is special                */
       /* If we're multiplexed, everyone is a group leader */
       if (( i == 0 ) || (ctl->multiplexed)) {
@@ -217,6 +273,13 @@ open_pe_events( pe_context_t *ctx, pe_control_t *ctl )
 							   ctl->inherit,
 							   0 );
       }
+#else
+             ctl->events[i].attr.pinned = !ctl->multiplexed;
+         	 ctl->events[i].attr.disabled = 1;
+         	 ctl->inherit = 1;
+         	 ctl->events[i].group_leader_fd=-1;
+             ctl->events[i].attr.read_format = get_read_format(ctl->multiplexed, ctl->inherit, 0 );
+#endif
 
 
       /* try to open */
@@ -239,7 +302,7 @@ open_pe_events( pe_context_t *ctx, pe_control_t *ctl )
 
       SUBDBG ("sys_perf_event_open: tid: %ld, cpu_num: %d,"
               " group_leader/fd: %d, event_fd: %d,"
-              " read_format: 0x%"PRIu64"\n",
+              " read_format: %#"PRIu64"\n",
 	      pid, ctl->cpu, ctl->events[i].group_leader_fd, 
 	      ctl->events[i].event_fd, ctl->events[i].attr.read_format);
 
@@ -532,7 +595,7 @@ _peu_update_control_state( hwd_control_state_t *ctl,
 	 ret=_peu_libpfm4_setup_counters(&pe_ctl->events[i].attr,
 					native[i].ni_event,
 					pe_ctx->event_table);
-	 SUBDBG( "pe_ctl->eventss[%d].config=%"PRIx64"\n",i,
+	 SUBDBG( "pe_ctl->eventss[%d].config=%#"PRIx64"\n",i,
 		 pe_ctl->events[i].attr.config);
 	 if (ret!=PAPI_OK) return ret;
 
