@@ -1,4 +1,4 @@
-/** 
+/**
  * @file    linux-rapl.c
  * @author  Vince Weaver
  *
@@ -6,10 +6,10 @@
  *
  * @brief rapl component
  *
- *  This component enables RAPL (Running Average Power Level) 
- *  energy measurements on Intel SandyBridge processors.
+ *  This component enables RAPL (Running Average Power Level)
+ *  energy measurements on Intel SandyBridge/IvyBridge/Haswell
  *
- *  To work, the x86 generic MSR driver must be installed 
+ *  To work, the x86 generic MSR driver must be installed
  *    (CONFIG_X86_MSR) and the /dev/cpu/?/msr files must have read permissions
  */
 
@@ -190,7 +190,7 @@ static long long read_rapl_value(int index) {
 
    fd=open_fd(rapl_native_events[index].fd_offset);
    return read_msr(fd,rapl_native_events[index].msr);
-   
+
 }
 
 static long long convert_rapl_energy(int index, long long value) {
@@ -272,7 +272,7 @@ get_kernel_nr_cpus(void)
 /*
  * This is called whenever a thread is initialized
  */
-int 
+int
 _rapl_init_thread( hwd_context_t *ctx )
 {
   ( void ) ctx;
@@ -282,10 +282,10 @@ _rapl_init_thread( hwd_context_t *ctx )
 
 
 
-/* 
+/*
  * Called when PAPI process is initialized (i.e. PAPI_library_init)
  */
-int 
+int
 _rapl_init_component( int cidx )
 {
      int i,j,k,fd;
@@ -313,7 +313,7 @@ _rapl_init_component( int cidx )
      /* check if Intel processor */
      hw_info=&(_papi_hwi_system_info.hw_info);
 
-     /* Ugh can't use PAPI_get_hardware_info() if 
+     /* Ugh can't use PAPI_get_hardware_info() if
 	PAPI library not done initializing yet */
 
      if (hw_info->vendor!=PAPI_VENDOR_INTEL) {
@@ -322,8 +322,7 @@ _rapl_init_component( int cidx )
         return PAPI_ENOSUPP;
      }
 
-     /* check if SandyBridge */
-
+     /* check model to support */
      if (hw_info->cpuid_family==6) {
        if (hw_info->cpuid_model==42) {
 	  /* SandyBridge */
@@ -345,7 +344,7 @@ _rapl_init_component( int cidx )
           pp0_avail=1;
           pp1_avail=1;
           dram_avail=0;
-       }	
+       }
        else if (hw_info->cpuid_model==62) {
 	  /* IvyBridge-EP */
           package_avail=1;
@@ -354,11 +353,20 @@ _rapl_init_component( int cidx )
           dram_avail=1;
        }
        else if (hw_info->cpuid_model==60 || hw_info->cpuid_model==69 || hw_info->cpuid_model==70 ) {
-	  /* Haswell */
-		  package_avail=1;
-		  pp0_avail=1;
-		  pp1_avail=1;dram_avail=0;
+		/* Haswell */
+		package_avail=1;
+		pp0_avail=1;
+		pp1_avail=1;
+		/* Not documented by Intel but seems to work */
+		dram_avail=1;
 	   }
+	else if ( hw_info->cpuid_model==63) {
+		/* Haswell-EP */
+		package_avail=1;
+		pp0_avail=1;
+		pp1_avail=0;
+		dram_avail=1;
+	}
        else {
 	 /* not a supported model */
 	 strncpy(_rapl_vector.cmp_info.disabled_reason,
@@ -749,10 +757,10 @@ _rapl_stop( hwd_context_t *ctx, hwd_control_state_t *ctl )
 			if (control->need_difference[i]) {
 				/* test for wrap around */
 				if (temp < context->start_value[i] ) {
-	        		SUBDBG("Wraparound!\nstart:\t0x%016x\ttemp:\t0x%016x",
+	        		SUBDBG("Wraparound!\nstart:\t%#016x\ttemp:\t%#016x",
 	        			(unsigned)context->start_value[i], (unsigned)temp);
 	           		temp += (0x100000000 - context->start_value[i]);
-	           		SUBDBG("\tresult:\t0x%016x\n", (unsigned)temp);
+	           		SUBDBG("\tresult:\t%#016x\n", (unsigned)temp);
 		  		} else {
 					temp -= context->start_value[i];
 		  		}
@@ -868,10 +876,11 @@ int
 _rapl_set_domain( hwd_control_state_t *ctl, int domain )
 {
     ( void ) ctl;
-    (void) domain;
     
     /* In theory we only support system-wide mode */
     /* How to best handle that? */
+    if ( PAPI_DOM_ALL != domain )
+	return PAPI_EINVAL;
 
     return PAPI_OK;
 }
@@ -987,13 +996,13 @@ papi_vector_t _rapl_vector = {
     .cmp_info = { /* (unspecified values are initialized to 0) */
        .name = "rapl",
        .short_name = "rapl",
-       .description = "Linux SandyBridge RAPL energy measurements",
+       .description = "Linux RAPL energy measurements",
        .version = "5.3.0",
-       .default_domain = PAPI_DOM_USER,
-       .default_granularity = PAPI_GRN_THR,
-       .available_granularities = PAPI_GRN_THR,
+       .default_domain = PAPI_DOM_ALL,
+       .default_granularity = PAPI_GRN_SYS,
+       .available_granularities = PAPI_GRN_SYS,
        .hardware_intr_sig = PAPI_INT_SIGNAL,
-       .available_domains = PAPI_DOM_USER | PAPI_DOM_KERNEL,
+       .available_domains = PAPI_DOM_ALL,
     },
 
 	/* sizes of framework-opaque component-private structures */
