@@ -162,10 +162,16 @@
    }
 
 static const intel_x86_umask_t snbep_unc_c_llc_lookup[]={
+   { .uname  = "ANY",
+     .udesc  = "Any request",
+     .grpid  = 0,
+     .uflags = INTEL_X86_NCOMBO,
+     .ucode = 0x1f00,
+   },
    { .uname  = "DATA_READ",
      .udesc  = "Data read requests",
      .grpid  = 0,
-     .uflags = INTEL_X86_NCOMBO,
+     .uflags = INTEL_X86_NCOMBO | INTEL_X86_DFL,
      .ucode = 0x300,
    },
    { .uname  = "WRITE",
@@ -181,13 +187,13 @@ static const intel_x86_umask_t snbep_unc_c_llc_lookup[]={
      .ucode = 0x900,
    },
    { .uname  = "NID",
-     .udesc  = "Match a given RTID destination NID",
-     .uflags = INTEL_X86_NCOMBO,
+     .udesc  = "Match a given RTID destination NID (must provide nf=X modifier)",
+     .uflags = INTEL_X86_NCOMBO | INTEL_X86_GRP_DFL_NONE,
      .umodmsk_req = _SNBEP_UNC_ATTR_NF,
-     .grpid  = 0,
+     .grpid  = 1,
      .ucode = 0x4100,
    },
-   CBO_FILT_MESIFS(1),
+   CBO_FILT_MESIFS(2),
 };
 
 static const intel_x86_umask_t snbep_unc_c_llc_victims[]={
@@ -208,7 +214,9 @@ static const intel_x86_umask_t snbep_unc_c_llc_victims[]={
      .ucode = 0x800,
    },
    { .uname  = "NID",
-     .udesc  = "Victimized Lines matching the NID filter",
+     .udesc  = "Victimized Lines matching the NID filter (must provide nf=X modifier)",
+     .uflags = INTEL_X86_NCOMBO,
+     .umodmsk_req = _SNBEP_UNC_ATTR_NF,
      .ucode = 0x4000,
    },
 };
@@ -438,7 +446,7 @@ static const intel_x86_umask_t snbep_unc_c_tor_inserts[]={
     .uflags = INTEL_X86_NCOMBO,
   },
   { .uname = "NID_ALL",
-    .udesc  = "Number of NID-matched transactions inserted into the TOR",
+    .udesc  = "Number of NID-matched transactions inserted into the TOR (must provide nf=X modifier)",
     .ucode  = 0x4800,
     .grpid  = 0,
     .umodmsk_req = _SNBEP_UNC_ATTR_NF,
@@ -580,7 +588,7 @@ static const intel_x86_umask_t snbep_unc_c_txr_inserts[]={
     .uflags = INTEL_X86_NCOMBO,
   },
   { .uname = "IV_CACHE",
-    .udesc  = "Counts the number of ring transactions from Cachebo ton IV ring",
+    .udesc  = "Counts the number of ring transactions from Cachebo to IV ring",
     .ucode  = 0x800,
     .uflags = INTEL_X86_NCOMBO,
   },
@@ -626,22 +634,23 @@ static const intel_x86_entry_t intel_snbep_unc_c_pe[]={
     .modmsk = SNBEP_UNC_CBO_NID_ATTRS,
     .cntmsk = 0x3,
     .code = 0x34,
-    .ngrp = 2,
+    .ngrp = 3,
     .flags = INTEL_X86_NO_AUTOENCODE,
     .numasks = LIBPFM_ARRAY_SIZE(snbep_unc_c_llc_lookup),
     .umasks = snbep_unc_c_llc_lookup,
   },
   { .name   = "UNC_C_LLC_VICTIMS",
     .desc   = "Lines victimized",
-    .modmsk = SNBEP_UNC_CBO_ATTRS,
+    .modmsk = SNBEP_UNC_CBO_NID_ATTRS,
     .cntmsk = 0x3,
     .code = 0x37,
+    .flags = INTEL_X86_NO_AUTOENCODE,
     .numasks = LIBPFM_ARRAY_SIZE(snbep_unc_c_llc_victims),
     .ngrp = 1,
     .umasks = snbep_unc_c_llc_victims,
   },
   { .name   = "UNC_C_MISC",
-    .desc   = "Miscelleanous C-Box events",
+    .desc   = "Miscellaneous C-Box events",
     .modmsk = SNBEP_UNC_CBO_ATTRS,
     .cntmsk = 0x3,
     .code = 0x39,
@@ -659,7 +668,7 @@ static const intel_x86_entry_t intel_snbep_unc_c_pe[]={
     .umasks = snbep_unc_c_ring_ad_used,
   },
   { .name   = "UNC_C_RING_AK_USED",
-    .desc   = "Acknowledgement ring in use. Counts number of cycles ring is being used at this ring stop",
+    .desc   = "Acknowledgment ring in use. Counts number of cycles ring is being used at this ring stop",
     .modmsk = SNBEP_UNC_CBO_ATTRS,
     .cntmsk = 0xc,
     .code = 0x1c,
@@ -701,7 +710,7 @@ static const intel_x86_entry_t intel_snbep_unc_c_pe[]={
     .code = 0x07,
   },
   { .name   = "UNC_C_RXR_EXT_STARVED",
-    .desc   = "Ingress arbiter blockig cycles",
+    .desc   = "Ingress arbiter blocking cycles",
     .modmsk = SNBEP_UNC_CBO_ATTRS,
     .cntmsk = 0x3,
     .code = 0x12,
